@@ -190,7 +190,11 @@ def cut(x, cuts):
     bns = {}
     for i in range(len(cuts) - 1):
         bns[i + 1] = {'type': 'Normal', 'lb': cuts[i], 'rb': cuts[i + 1]}
-    xe = enc_apl(bns, x, 'num', 'int')
+    bng = {'xtp': 'num',
+           'bns': bns,
+         'cname': 'var_01'
+        }
+    xe, _ = enc_apl(bng, x, 'int')
     return xe
 
 
