@@ -188,7 +188,7 @@ def mdl(x, y, w, ivi, n2, st0, pm0, cnames, metpminit, meth, maxiter, fcnv, afcn
     func = 1
     grad = 1
     hes = 1
-    pm, F, g, H, Hinv, __ = newton(pm, func, grad, hes, args, meth, maxiter, fcnv, afcnv, xcnv, gcnv, sc, dsp_op, smeth, su, p_decr, p_incr)
+    pm, F, g, H, Hinv, __ = newton(pm, f_lgr, g_lgr, h_lgr, args, meth, maxiter, fcnv, afcnv, xcnv, gcnv, sc, dsp_op, smeth, su, p_decr, p_incr)
     # # Denormalization
     # pm = denormPar(dset, pmn);
 
