@@ -377,23 +377,24 @@ def lspm(U, Y, na=0, nb=0, pm0=False, w=None):
              Pm = [A1 A2 ... Ana B1 B2 ... Bnb]'
         mod.par
     """
+
+    n = max(na, nb)
+    N = len(Y)
     Pm = np.empty((0, 0))
     if max(na, nb) == 0:
         if pm0: U = np.hstack((np.ones((U.shape[0], 1)), U))
-        if w == None:
-            Pm = nsinv(U.T@U)@U.T@Y
+        if w is None:
+            Pm = nsinv(U.T @ U) @ U.T @ Y
         else:
-            W = np.diag(w[n:N])
-            Pm = nsinv(U.T@W@U)@U.T@W@Y[n:N][:]
+            W = np.diag(w[n:N].flatten())
+            Pm = nsinv(U.T @ W @ U) @ U.T @ W @ Y[n:N][:]
     else:
-        n = max(na, nb)
-        N = len(Y)
         F = dmpm(U, Y, na=na, nb=nb, nc=0, pm0=pm0)
         if w == None:
-            Pm = nsinv(F.T@F)@F.T@Y[n:N][:]  # <<< think about Pseudoinverse
+            Pm = nsinv(F.T @ F) @ F.T @ Y[n:N][:]  # <<< think about Pseudoinverse
         else:
             W = np.diag(w[n:N])
-            Pm = nsinv(F.T@W@F)@F.T@W@Y[n:N][:]
+            Pm = nsinv(F.T @ W @ F) @ F.T @ W @ Y[n:N][:]
     return Pm
 
 
