@@ -12,14 +12,13 @@ from .nlopt import *
 # ###################################################################################
 # def cgrad():
 ###################################################################################
-def newton(x, func, grad, hes, args, met_opt='newt', maxiter=50, fcnv=None, afcnv=None, xcnv=None, gcnv=1e-6, sc=None, dsp_op=[2], smeth='fprev2', su=1, p_incr=1.2, p_decr=0.6, rcondH=1e-6):
+def newton(x, func, grad, hes, args, met_opt='newt', maxiter=50, fcnv=None, afcnv=None, xcnv=None, gcnv=1e-6, sc=None, dsp_op=[2], smeth='fprev2', su=1, p_incr=1.2, p_decr=0.6, rcondH=1e-6, s=1):
 # Newton-Raphson Method
 #---------------------------------------------
 # Author: Alexander Efemov
 # Date:   20.12.2009
 # Course: Modelling and Processes Optimization
 #---------------------------------------------
-    s = 1
     tmp = {}
     tmp['F'] = np.inf
     xx = []
@@ -29,6 +28,32 @@ def newton(x, func, grad, hes, args, met_opt='newt', maxiter=50, fcnv=None, afcn
     flg_omit = 0
     iterate = 1
     itr = 0
+
+
+    # #########################################################
+    # ah = args['data'].shape[1]
+    # ax = args['data'][:, np.arange(0, ah - 3)]
+    # ay = c_(args['data'][:, -3])
+    # # aw = c_(args['data'][:, -2])
+    # apm = args['x']
+    # if x.shape[1] == 0: ax = c_(ax)
+    # aym = apl_expW(ax, apm)
+    # ae = ay - aym
+    #
+    # import matplotlib.pyplot as plt
+    #
+    # plt.scatter(ax, ay)
+    # plt.plot(ax, apl_expW(ax, apm), 'r')
+    # plt.show()
+    # # print(ae.T @ ae)
+    #
+    # import matplotlib.pyplot as plt
+    #
+    # plt.scatter(ax, ay)
+    # plt.plot(ax, apl_expW(ax, apm), 'k')
+    # plt.show()
+    # #########################################################
+
     while iterate:
         if not len(F) == 0:
             if itr == 1: FF = np.ones((3,1))*F
@@ -82,12 +107,52 @@ def newton(x, func, grad, hes, args, met_opt='newt', maxiter=50, fcnv=None, afcn
         x = x + mu*p
         args['x'] = x
         itr = itr + 1
-    # end of optimization cycle
+
+        # #########################################################
+        # ah = args['data'].shape[1]
+        # ax = args['data'][:, np.arange(0, ah - 3)]
+        # ay = c_(args['data'][:, -3])
+        # # aw = c_(args['data'][:, -2])
+        # apm = args['x']
+        # if x.shape[1] == 0: ax = c_(ax)
+        # aym = apl_expW(ax, apm)
+        # ae = ay - aym
+        #
+        # import matplotlib.pyplot as plt
+        #
+        # plt.scatter(ax, ay)
+        # plt.plot(ax, apl_expW(ax, apm), 'r')
+        # plt.show()
+        # # print(ae.T@ae)
+        # #########################################################
+
+# end of optimization cycle
     if not msg != None: msg = 'E'
     if len(Hinv) == 0:
         rcH = 1/np.linalg.cond(H)
         if rcH < 1e-6: Hinv = nsinv(H)
         else:          Hinv = np.linalg.inv(H)
     if dsp_op: dspl(flg=1, x=x, xx=xx, F=F, FF=FF, g=g, H=H, itr=itr, msg=msg, maxiter=maxiter, fcnv=fcnv, afcnv=afcnv, xcnv=xcnv, gcnv=gcnv)
+
+
+    # #########################################################
+    # ah = args['data'].shape[1]
+    # ax = args['data'][:, np.arange(0, ah - 3)]
+    # ay = c_(args['data'][:, -3])
+    # # aw = c_(args['data'][:, -2])
+    # apm = args['x']
+    # if x.shape[1] == 0: ax = c_(ax)
+    # aym = apl_expW(ax, apm)
+    #
+    # ae = ay - aym
+    #
+    # import matplotlib.pyplot as plt
+    #
+    # plt.scatter(ax, ay)
+    # plt.plot(ax, apl_expW(ax, apm), 'r')
+    # plt.show()
+    # # print(ae.T@ae)
+    # #########################################################
+
     return x, F, g, H, Hinv, itr
 
